@@ -2,7 +2,7 @@
  *
  * grapper.c - Raptor GTK GUI example code
  *
- * $Id: grapper.c,v 1.20 2005/02/16 23:38:46 cmdjb Exp $
+ * $Id: grapper.c,v 1.22 2005/07/27 17:22:23 cmdjb Exp $
  *
  * Copyright (C) 2003-2005, David Beckett http://purl.org/net/dajobe/
  * Institute for Learning and Research Technology http://www.ilrt.bristol.ac.uk/
@@ -463,6 +463,8 @@ url_entry_callback(GtkWidget *widget, gpointer data)
   grapper_model_parse(state);
 }
 
+#if GTK_CHECK_VERSION(2,4,0)
+#else
 /* file selection OK button clicked callback */
 static void
 fs_ok_button_callback(GtkWidget *widget, gpointer data)
@@ -483,6 +485,7 @@ fs_ok_button_callback(GtkWidget *widget, gpointer data)
 
   grapper_model_parse(state);
 }
+#endif
 
 /* open button clicked callback */
 static void
@@ -504,7 +507,7 @@ open_button_callback(GtkWidget *widget, gpointer data)
 
   if (gtk_dialog_run(GTK_DIALOG (files)) == GTK_RESPONSE_ACCEPT) {
     state->filename=gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(files));
-    uri_string=gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(files));
+    uri_string=(unsigned char*)gtk_file_chooser_get_uri(GTK_FILE_CHOOSER(files));
     grapper_model_set_url(state, uri_string);
     g_free(uri_string);
 
@@ -623,7 +626,7 @@ about_menu_callback(gpointer data, guint action, GtkWidget *widget)
 
 #if GTK_CHECK_VERSION(2,5,0)
   /* 2.5.x about widget */
-  const gchar* authors[2]= { "Dave Beckett", NULL };
+  const gchar* authors[2]= { "Dave Beckett http://purl.org/net/dajobe/", NULL };
 
 #if 1
   /* using 2.5.x stock about */
